@@ -1,9 +1,10 @@
 ## File Name: load.Rdata2.R
-## File Version: 1.06
+## File Version: 1.07
 
 #**********************************************
 # load Rdata objects
-load.Rdata2 <- function( filename, path=getwd() ){
+load.Rdata2 <- function( filename, path=getwd() )
+{
     d1 <- load( file=file.path(path,filename) )
     objname <- "ma01"
     eval(parse(text=paste(objname, "<- ", d1)))
